@@ -1,6 +1,6 @@
 package Date::Holidays::GB;
 
-our $VERSION = '0.011';
+our $VERSION = '0.012';
 
 # ABSTRACT: Determine British holidays - Current UK public and bank holiday dates up to 2019
 
@@ -174,7 +174,7 @@ sub _holiday {
     return join( ', ', @strings );
 }
 
-sub date_generated { '2017-12-11' }
+sub date_generated { '2019-01-09' }
 
 1;
 
@@ -398,3 +398,30 @@ __DATA__
 2019-12-26	EAW	Boxing Day
 2019-12-26	NIR	Boxing Day
 2019-12-26	SCT	Boxing Day
+2020-01-01	EAW	New Year’s Day
+2020-01-01	NIR	New Year’s Day
+2020-01-01	SCT	New Year’s Day
+2020-01-02	SCT	2nd January
+2020-03-17	NIR	St Patrick’s Day
+2020-04-10	EAW	Good Friday
+2020-04-10	NIR	Good Friday
+2020-04-10	SCT	Good Friday
+2020-04-13	EAW	Easter Monday
+2020-04-13	NIR	Easter Monday
+2020-05-04	EAW	Early May bank holiday
+2020-05-04	NIR	Early May bank holiday
+2020-05-04	SCT	Early May bank holiday
+2020-05-25	EAW	Spring bank holiday
+2020-05-25	NIR	Spring bank holiday
+2020-05-25	SCT	Spring bank holiday
+2020-07-13	NIR	Battle of the Boyne (Orangemen’s Day)
+2020-08-03	SCT	Summer bank holiday
+2020-08-31	EAW	Summer bank holiday
+2020-08-31	NIR	Summer bank holiday
+2020-11-30	SCT	St Andrew’s Day
+2020-12-25	EAW	Christmas Day
+2020-12-25	NIR	Christmas Day
+2020-12-25	SCT	Christmas Day
+2020-12-28	EAW	Boxing Day
+2020-12-28	NIR	Boxing Day
+2020-12-28	SCT	Boxing Day
